
.. image:: https://github.com/ArangoDB-Community/ArangoRDF/actions/workflows/build.yml/badge.svg?branch=main
   :target: https://github.com/ArangoDB-Community/ArangoRDF/actions/workflows/build.yml

.. image:: https://github.com/ArangoDB-Community/ArangoRDF/actions/workflows/analyze.yml/badge.svg?branch=main
   :target: https://github.com/ArangoDB-Community/ArangoRDF/actions/workflows/analyze.yml

.. image:: https://coveralls.io/repos/github/ArangoDB-Community/ArangoRDF/badge.svg?branch=main
   :target: https://coveralls.io/github/ArangoDB-Community/ArangoRDF?branch=main

.. image:: https://img.shields.io/github/last-commit/ArangoDB-Community/ArangoRDF
   :target: https://github.com/ArangoDB-Community/ArangoRDF/commits/main

\

.. image:: https://img.shields.io/pypi/v/arango-rdf?color=3775A9&style=for-the-badge&logo=pypi&logoColor=FFD43B
   :target: https://pypi.org/project/arango-rdf/

.. image:: https://img.shields.io/pypi/pyversions/arango-rdf?color=3776AB&style=for-the-badge&logo=python&logoColor=FFD43B
   :target: https://pypi.org/project/arango-rdf/

\

.. image:: https://img.shields.io/github/license/ArangoDB-Community/ArangoRDF?color=9E2165&style=for-the-badge
   :target: https://github.com/ArangoDB-Community/ArangoRDF/blob/main/LICENSE
.. image:: https://img.shields.io/static/v1?style=for-the-badge&label=code%20style&message=black&color=black
   :target: https://github.com/psf/black
.. image:: https://img.shields.io/pepy/dt/arango-rdf?style=for-the-badge&color=282661
   :target: https://pepy.tech/project/arango-rdf

\

.. image:: _static/adb_logo.png
   :width: 50px
   :alt: ArangoDB

.. image:: _static/rdf_logo.png
   :width: 50px
   :alt: RDF

\

ArangoRDF
---------

Convert RDF Graphs to ArangoDB, and vice-versa.


Requirements
============

- Python 3.8+
- ArangoDB 3.10+

Installation
============

Latest Release

.. code-block::

   pip install arango-rdf

Current State

.. code-block::

   pip install git+https://github.com/ArangoDB-Community/ArangoRDF


Contents
========

.. toctree::
   :maxdepth: 1

   quickstart
   rdf_to_arangodb_rpt
   rdf_to_arangodb_pgt
   specs
